@@ -489,6 +489,26 @@ static int win32_lstat(const char* path, struct stat* sbuf)
   return result;
 }
 
+// Original implementation
+static int win32_realpath(const char* path, char* out_path, int32_t out_path_length) {
+  
+  int32_t len = 0; // 0 indicates an error
+  HANDLE hFile = CreateFileA(path, GENERIC_READ, 0, NULL, OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, 0);
+  
+  if (hFile == INVALID_HANDLE_VALUE) {
+    len = -1;
+    goto END_OF_FUNC;
+  }
+  
+  len = GetFinalPathNameByHandleA(hFile, out_path, out_path_length, 0);
+  
+  END_OF_FUNC:
+  
+  CloseHandle(hFile);
+  
+  return len;
+}
+
 #endif // _WIN32
 
 int32_t SPVM__Sys__IO__Windows__unlink(SPVM_ENV* env, SPVM_VALUE* stack) {
@@ -658,3 +678,52 @@ int32_t SPVM__Sys__IO__Windows__lstat(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Sys__IO__Windows__realpath(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if !defined(_WIN32)
+  return env->die(env, stack, "Sys::IO::Windows#realpath method is not supported in this system(!defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+#else
+  
+  void* obj_path = stack[0].oval;
+  
+  void* obj_resolved_path = stack[1].oval;
+  
+  if (!obj_path) {
+    return env->die(env, stack, "The path $path must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  if (obj_resolved_path) {
+    return env->die(env, stack, "The resolved path $resolved_path must not be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  const char* path = env->get_chars(env, stack, obj_path);
+  
+  int32_t len = win32_realpath(path, NULL, 0);
+  if (len == -1) {
+    env->die(env, stack, "[System Error]CreateFile() failed:the symbolic link is not permitted, broken or not found. $path:\"%s\".", path, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  else if (!(len > 0)) {
+    env->die(env, stack, "[System Error]win32_realpath() failed:GetLastError() %d. $path:\"%s\".", GetLastError(), path, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  obj_resolved_path = env->new_string(env, stack, NULL, len + 1);
+  char* resolved_path = (char*)env->get_chars(env, stack, obj_resolved_path);
+  
+  len = win32_realpath(path, resolved_path, len + 1);
+  if (!(len > 0)) {
+    env->die(env, stack, "[System Error]win32_realpath() failed:GetLastError() %d. $path:\"%s\".", GetLastError(), path, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  for (int32_t i = 0; i < len; i++) {
+    if (resolved_path[i] == '\\') {
+      resolved_path[i] = '/';
+    }
+  }
+  
+  stack[0].oval = obj_resolved_path;
+  
+  return 0;
+#endif
+}
